@@ -29,9 +29,9 @@ class View:
     def flash(self, message, num=None, **kwargs):
         if num :
             try:
-                message, category = nt(message[0], message[1], num=num), self.messages[message]
+                message, category = nt(message[0], message[1], num=num), self.messages[message[0], message[1]]
             except KeyError:
-                message, category = nt(message, message, num=num), self.messages[message]
+                message, category = nt(message, message, num=num), self.messages[message, message]
         else:
             message, category = t(message), self.messages[message]
         return flash(message.format(**kwargs), category)
